service_map <- list(
  # deprecated
  #   'v201405'=
  #     c('ActivityGroupService', 'ActivityService', 'AdRuleService',
  #      'AudienceSegmentService', 'BaseRateService', 'CompanyService',
  #      'ContactService', 'ContentBundleService',
  #      'ContentMetadataKeyHierarchyService', 'ContentService',
  #      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
  #      'CreativeWrapperService', 'CustomFieldService',
  #      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
  #      'InventoryService', 'LabelService',
  #      'LineItemCreativeAssociationService', 'LineItemService',
  #      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
  #      'OrderService', 'PlacementService', 'ProductService',
  #      'ProductTemplateService', 'ProposalLineItemService', 'ProposalService',
  #      'PublisherQueryLanguageService', 'RateCardCustomizationService',
  #      'RateCardCustomizationGroupService', 'RateCardService',
  #      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
  #      'ReconciliationReportService', 'ReportService',
  #      'SuggestedAdUnitService', 'TeamService', 'UserService',
  #      'UserTeamAssociationService', 'WorkflowRequestService'),
  #   'v201408'=
  #     c('ActivityGroupService', 'ActivityService', 'AdRuleService',
  #      'AudienceSegmentService', 'BaseRateService', 'CompanyService',
  #      'ContactService', 'ContentBundleService',
  #      'ContentMetadataKeyHierarchyService', 'ContentService',
  #      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
  #      'CreativeWrapperService', 'CustomFieldService',
  #      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
  #      'InventoryService', 'LabelService',
  #      'LineItemCreativeAssociationService', 'LineItemService',
  #      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
  #      'OrderService', 'PlacementService', 'PremiumRateService',
  #      'ProductService', 'ProductTemplateService', 'ProposalLineItemService',
  #      'ProposalService', 'PublisherQueryLanguageService', 'RateCardService',
  #      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
  #      'ReconciliationReportService', 'ReportService',
  #      'SuggestedAdUnitService', 'TeamService', 'UserService',
  #      'UserTeamAssociationService', 'WorkflowRequestService'),
  #   'v201411'=
  #     c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
  #      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
  #      'CompanyService', 'ContactService', 'ContentBundleService',
  #      'ContentMetadataKeyHierarchyService', 'ContentService',
  #      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
  #      'CreativeWrapperService', 'CustomFieldService',
  #      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
  #      'InventoryService', 'LabelService',
  #      'LineItemCreativeAssociationService', 'LineItemService',
  #      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
  #      'OrderService', 'PlacementService', 'PremiumRateService',
  #      'ProductService', 'ProductTemplateService', 'ProposalLineItemService',
  #      'ProposalService', 'PublisherQueryLanguageService', 'RateCardService',
  #      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
  #      'ReconciliationReportService', 'ReportService', 'SharedAdUnitService',
  #      'SuggestedAdUnitService', 'TeamService', 'UserService',
  #      'UserTeamAssociationService', 'WorkflowRequestService'),
  #   'v201502'=
  #     c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
  #      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
  #      'CompanyService', 'ContactService', 'ContentBundleService',
  #      'ContentMetadataKeyHierarchyService', 'ContentService',
  #      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
  #      'CreativeWrapperService', 'CustomFieldService',
  #      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
  #      'InventoryService', 'LabelService',
  #      'LineItemCreativeAssociationService', 'LineItemService',
  #      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
  #      'OrderService', 'PackageService', 'PlacementService',
  #      'PremiumRateService', 'ProductService', 'ProductPackageService',
  #      'ProductPackageItemService', 'ProductTemplateService',
  #      'ProposalLineItemService', 'ProposalService',
  #      'PublisherQueryLanguageService', 'RateCardService',
  #      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
  #      'ReconciliationReportService', 'ReportService', 'SharedAdUnitService',
  #      'SuggestedAdUnitService', 'TeamService', 'UserService',
  #      'UserTeamAssociationService', 'WorkflowRequestService'),
  #   'v201505'=
  #     c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
  #      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
  #      'CompanyService', 'ContactService', 'ContentBundleService',
  #      'ContentMetadataKeyHierarchyService', 'ContentService',
  #      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
  #      'CreativeWrapperService', 'CustomFieldService',
  #      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
  #      'InventoryService', 'LabelService',
  #      'LineItemCreativeAssociationService', 'LineItemService',
  #      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
  #      'OrderService', 'PackageService', 'PlacementService',
  #      'PremiumRateService', 'ProductService', 'ProductPackageService',
  #      'ProductPackageItemService', 'ProductTemplateService',
  #      'ProposalLineItemService', 'ProposalService',
  #      'PublisherQueryLanguageService', 'RateCardService',
  #      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
  #      'ReconciliationReportService', 'ReportService', 'SharedAdUnitService',
  #      'SuggestedAdUnitService', 'TeamService', 'UserService',
  #      'UserTeamAssociationService', 'WorkflowRequestService'),
  # 'v201508'=
  #   c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
  #    'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
  #    'CompanyService', 'ContactService', 'ContentBundleService',
  #    'ContentMetadataKeyHierarchyService', 'ContentService',
  #    'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
  #    'CreativeWrapperService', 'CustomFieldService',
  #    'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
  #    'InventoryService', 'LabelService',
  #    'LineItemCreativeAssociationService', 'LineItemService',
  #    'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
  #    'OrderService', 'PackageService', 'PlacementService',
  #    'PremiumRateService', 'ProductService', 'ProductPackageService',
  #    'ProductPackageItemService', 'ProductTemplateService',
  #    'ProposalLineItemService', 'ProposalService',
  #    'PublisherQueryLanguageService', 'RateCardService',
  #    'ReconciliationOrderReportService', 'ReconciliationReportRowService',
  #    'ReconciliationLineItemReportService',
  #    'ReconciliationReportService', 'ReportService', 'SharedAdUnitService',
  #    'SuggestedAdUnitService', 'TeamService', 'UserService',
  #    'UserTeamAssociationService', 'WorkflowRequestService'),
  # 'v201511'=
  #   c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
  #     'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
  #     'CompanyService', 'ContactService', 'ContentBundleService',
  #     'ContentMetadataKeyHierarchyService', 'ContentService',
  #     'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
  #     'CreativeWrapperService', 'CustomFieldService',
  #     'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
  #     'InventoryService', 'LabelService',
  #     'LineItemCreativeAssociationService', 'LineItemService',
  #     'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
  #     'OrderService', 'PackageService', 'PlacementService',
  #     'PremiumRateService', 'ProductService', 'ProductPackageService',
  #     'ProductPackageItemService', 'ProductTemplateService',
  #     'ProposalLineItemService', 'ProposalService',
  #     'PublisherQueryLanguageService', 'RateCardService',
  #     'ReconciliationOrderReportService', 'ReconciliationReportRowService',
  #     'ReconciliationLineItemReportService',
  #     'ReconciliationReportService', 'ReportService', 'SharedAdUnitService',
  #     'SuggestedAdUnitService', 'TeamService', 'UserService',
  #     'UserTeamAssociationService', 'WorkflowRequestService'),
  # 'v201602'=
  #   c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
  #    'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
  #    'CompanyService', 'ContactService', 'ContentBundleService',
  #    'ContentMetadataKeyHierarchyService', 'ContentService',
  #    'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
  #    'CreativeWrapperService', 'CustomFieldService',
  #    'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
  #    'InventoryService', 'LabelService',
  #    'LineItemCreativeAssociationService', 'LineItemService',
  #    'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
  #    'OrderService', 'PackageService', 'PlacementService',
  #    'PremiumRateService', 'ProductService', 'ProductPackageService',
  #    'ProductPackageItemService', 'ProductTemplateService',
  #    'ProposalLineItemService', 'ProposalService',
  #    'PublisherQueryLanguageService', 'RateCardService',
  #    'ReconciliationOrderReportService', 'ReconciliationReportRowService',
  #    'ReconciliationLineItemReportService',
  #    'ReconciliationReportService', 'ReportService',
  #    'SuggestedAdUnitService', 'TeamService', 'UserService',
  #    'UserTeamAssociationService', 'WorkflowRequestService'),
  # 'v201605'=
  #   c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
  #      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
  #      'CompanyService', 'ContactService', 'ContentBundleService',
  #      'ContentMetadataKeyHierarchyService', 'ContentService',
  #      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
  #      'CreativeWrapperService', 'CustomFieldService',
  #      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
  #      'InventoryService', 'LabelService',
  #      'LineItemCreativeAssociationService', 'LineItemService',
  #      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
  #      'OrderService', 'PackageService', 'PlacementService',
  #      'PremiumRateService', 'ProductService', 'ProductPackageService',
  #      'ProductPackageItemService', 'ProductTemplateService',
  #      'ProposalLineItemService', 'ProposalService',
  #      'PublisherQueryLanguageService', 'RateCardService',
  #      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
  #      'ReconciliationLineItemReportService',
  #      'ReconciliationReportService', 'ReportService',
  #      'SuggestedAdUnitService', 'TeamService', 'UserService',
  #      'UserTeamAssociationService', 'WorkflowRequestService'),
  # 'v201608'=
  #   c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
  #      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
  #      'CompanyService', 'ContactService', 'ContentBundleService',
  #      'ContentMetadataKeyHierarchyService', 'ContentService',
  #      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
  #      'CreativeWrapperService', 'CustomFieldService',
  #      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
  #      'InventoryService', 'LabelService',
  #      'LineItemCreativeAssociationService', 'LineItemService',
  #      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
  #      'OrderService', 'PackageService', 'PlacementService',
  #      'PremiumRateService', 'ProductService', 'ProductPackageService',
  #      'ProductPackageItemService', 'ProductTemplateService',
  #      'ProposalLineItemService', 'ProposalService',
  #      'PublisherQueryLanguageService', 'RateCardService',
  #      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
  #      'ReconciliationLineItemReportService',
  #      'ReconciliationReportService', 'ReportService',
  #      'SuggestedAdUnitService', 'TeamService', 'UserService',
  #      'UserTeamAssociationService', 'WorkflowRequestService'),
  # 'v201611'=
  #   c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
  #      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
  #      'CompanyService', 'ContactService', 'ContentBundleService',
  #      'ContentMetadataKeyHierarchyService', 'ContentService',
  #      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
  #      'CreativeWrapperService', 'CustomFieldService',
  #      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
  #      'InventoryService', 'LabelService',
  #      'LineItemCreativeAssociationService', 'LineItemService',
  #      'LineItemTemplateService', 'LiveStreamEventService',
  #      'MobileApplicationService', 'NetworkService', 'OrderService',
  #      'PackageService', 'PlacementService', 'PremiumRateService',
  #      'ProductService', 'ProductPackageService', 'ProductPackageItemService',
  #      'ProductTemplateService', 'ProposalLineItemService', 'ProposalService',
  #      'PublisherQueryLanguageService', 'RateCardService',
  #      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
  #      'ReconciliationLineItemReportService',
  #      'ReconciliationReportService', 'ReportService',
  #      'SuggestedAdUnitService', 'TeamService', 'UserService',
  #      'UserTeamAssociationService', 'WorkflowRequestService'),
  # 'v201702'=
  #   c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
  #      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
  #      'CompanyService', 'ContactService', 'ContentBundleService',
  #      'ContentMetadataKeyHierarchyService', 'ContentService',
  #      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
  #      'CreativeWrapperService', 'CustomFieldService',
  #      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
  #      'InventoryService', 'LabelService',
  #      'LineItemCreativeAssociationService', 'LineItemService',
  #      'LineItemTemplateService', 'LiveStreamEventService',
  #      'MobileApplicationService', 'NativeStyleService', 'NetworkService',
  #      'OrderService', 'PackageService', 'PlacementService',
  #      'PremiumRateService', 'ProductService', 'ProductPackageService',
  #      'ProductPackageItemService', 'ProductTemplateService',
  #      'ProposalLineItemService', 'ProposalService',
  #      'PublisherQueryLanguageService', 'RateCardService',
  #      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
  #      'ReconciliationLineItemReportService',
  #      'ReconciliationReportService', 'ReportService',
  #      'SuggestedAdUnitService', 'TeamService', 'UserService',
  #      'UserTeamAssociationService', 'WorkflowRequestService'),
  'v201705'=
    c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
      'CompanyService', 'ContactService', 'ContentBundleService',
      'ContentMetadataKeyHierarchyService', 'ContentService',
      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
      'CreativeWrapperService', 'CustomFieldService',
      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
      'InventoryService', 'LabelService',
      'LineItemCreativeAssociationService', 'LineItemService',
      'LineItemTemplateService', 'LiveStreamEventService',
      'MobileApplicationService', 'NativeStyleService', 'NetworkService',
      'OrderService', 'PackageService', 'PlacementService',
      'PremiumRateService', 'ProductService', 'ProductPackageService',
      'ProductPackageItemService', 'ProductTemplateService',
      'ProposalLineItemService', 'ProposalService',
      'PublisherQueryLanguageService', 'RateCardService',
      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
      'ReconciliationLineItemReportService',
      'ReconciliationReportService', 'ReportService',
      'SuggestedAdUnitService', 'TeamService', 'UserService',
      'UserTeamAssociationService', 'WorkflowRequestService'),
  'v201708'=
    c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
      'CompanyService', 'ContactService', 'ContentBundleService',
      'ContentMetadataKeyHierarchyService', 'ContentService',
      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
      'CreativeWrapperService', 'CustomFieldService',
      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
      'InventoryService', 'LabelService',
      'LineItemCreativeAssociationService', 'LineItemService',
      'LineItemTemplateService', 'LiveStreamEventService',
      'MobileApplicationService', 'NativeStyleService', 'NetworkService',
      'OrderService', 'PackageService', 'PlacementService',
      'PremiumRateService', 'ProductService', 'ProductPackageService',
      'ProductPackageItemService', 'ProductTemplateService',
      'ProposalLineItemService', 'ProposalService',
      'PublisherQueryLanguageService', 'RateCardService',
      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
      'ReconciliationLineItemReportService',
      'ReconciliationReportService', 'ReportService',
      'SuggestedAdUnitService', 'TeamService', 'UserService',
      'UserTeamAssociationService', 'WorkflowRequestService'),
  'v201711'=
    c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
      'CdnConfigurationService', 'CompanyService', 'ContactService',
      'ContentBundleService', 'ContentMetadataKeyHierarchyService',
      'ContentService', 'CreativeService', 'CreativeSetService',
      'CreativeTemplateService', 'CreativeWrapperService',
      'CustomFieldService', 'CustomTargetingService', 'ExchangeRateService',
      'ForecastService', 'InventoryService', 'LabelService',
      'LineItemCreativeAssociationService', 'LineItemService',
      'LineItemTemplateService', 'LiveStreamEventService',
      'MobileApplicationService', 'NativeStyleService', 'NetworkService',
      'OrderService', 'PackageService', 'PlacementService',
      'PremiumRateService', 'ProductService', 'ProductPackageService',
      'ProductPackageItemService', 'ProductTemplateService',
      'ProposalLineItemService', 'ProposalService',
      'PublisherQueryLanguageService', 'RateCardService',
      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
      'ReconciliationLineItemReportService',
      'ReconciliationReportService', 'ReportService',
      'SuggestedAdUnitService', 'TeamService', 'UserService',
      'UserTeamAssociationService', 'WorkflowRequestService'),
  'v201802'=
    c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
      'CdnConfigurationService', 'CompanyService', 'ContactService',
      'ContentBundleService', 'ContentMetadataKeyHierarchyService',
      'ContentService', 'CreativeService', 'CreativeSetService',
      'CreativeTemplateService', 'CreativeWrapperService',
      'CustomFieldService', 'CustomTargetingService', 'ExchangeRateService',
      'ForecastService', 'InventoryService', 'LabelService',
      'LineItemCreativeAssociationService', 'LineItemService',
      'LineItemTemplateService', 'LiveStreamEventService',
      'MobileApplicationService', 'NativeStyleService', 'NetworkService',
      'OrderService', 'PackageService', 'PlacementService',
      'PremiumRateService', 'ProductService', 'ProductPackageService',
      'ProductPackageItemService', 'ProductTemplateService',
      'ProposalLineItemService', 'ProposalService',
      'PublisherQueryLanguageService', 'RateCardService',
      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
      'ReconciliationLineItemReportService',
      'ReconciliationReportService', 'ReportService',
      'SuggestedAdUnitService', 'TeamService', 'UserService',
      'UserTeamAssociationService', 'WorkflowRequestService'),
  'v201805'=
    c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
      'CdnConfigurationService', 'CompanyService', 'ContactService',
      'ContentBundleService', 'ContentMetadataKeyHierarchyService',
      'ContentService', 'CreativeService', 'CreativeSetService',
      'CreativeTemplateService', 'CreativeWrapperService',
      'CustomFieldService', 'CustomTargetingService',
      'DaiAuthenticationKeyService', 'ExchangeRateService',
      'ForecastService', 'InventoryService', 'LabelService',
      'LineItemCreativeAssociationService', 'LineItemService',
      'LineItemTemplateService', 'LiveStreamEventService',
      'MobileApplicationService', 'NativeStyleService', 'NetworkService',
      'OrderService', 'PackageService', 'PlacementService',
      'PremiumRateService', 'ProductService', 'ProductPackageService',
      'ProductPackageItemService', 'ProductTemplateService',
      'ProposalLineItemService', 'ProposalService',
      'PublisherQueryLanguageService', 'RateCardService',
      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
      'ReconciliationLineItemReportService',
      'ReconciliationReportService', 'ReportService',
      'SuggestedAdUnitService', 'TeamService', 'UserService',
      'UserTeamAssociationService', 'WorkflowRequestService'),
  'v201808'=
    c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
      'CdnConfigurationService', 'CompanyService', 'ContactService',
      'ContentBundleService', 'ContentMetadataKeyHierarchyService',
      'ContentService', 'CreativeService', 'CreativeSetService',
      'CreativeTemplateService', 'CreativeWrapperService',
      'CustomFieldService', 'CustomTargetingService',
      'DaiAuthenticationKeyService', 'ExchangeRateService',
      'ForecastService', 'InventoryService', 'LabelService',
      'LineItemCreativeAssociationService', 'LineItemService',
      'LineItemTemplateService', 'LiveStreamEventService',
      'MobileApplicationService', 'NativeStyleService', 'NetworkService',
      'OrderService', 'PackageService', 'PlacementService',
      'PremiumRateService', 'ProductService', 'ProductPackageService',
      'ProductPackageItemService', 'ProductTemplateService',
      'ProposalLineItemService', 'ProposalService',
      'PublisherQueryLanguageService', 'RateCardService',
      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
      'ReconciliationLineItemReportService',
      'ReconciliationReportService', 'ReportService',
      'SuggestedAdUnitService', 'TeamService', 'UserService',
      'UserTeamAssociationService', 'WorkflowRequestService'),
  'v201811'=
    c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
      'CdnConfigurationService', 'CompanyService', 'ContactService',
      'ContentBundleService', 'ContentService', 'CreativeService',
      'CreativeSetService', 'CreativeTemplateService',
      'CreativeWrapperService', 'CustomFieldService',
      'CustomTargetingService', 'DaiAuthenticationKeyService',
      'ExchangeRateService', 'ForecastService', 'InventoryService',
      'LabelService', 'LineItemCreativeAssociationService',
      'LineItemService', 'LineItemTemplateService', 'LiveStreamEventService',
      'MobileApplicationService', 'NativeStyleService', 'NetworkService',
      'OrderService', 'PackageService', 'PlacementService',
      'PremiumRateService', 'ProductService', 'ProductPackageService',
      'ProductPackageItemService', 'ProductTemplateService',
      'ProposalLineItemService', 'ProposalService',
      'PublisherQueryLanguageService', 'RateCardService',
      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
      'ReconciliationLineItemReportService',
      'ReconciliationReportService', 'ReportService',
      'SuggestedAdUnitService', 'TeamService', 'UserService',
      'UserTeamAssociationService', 'WorkflowRequestService'),
  'v201902'=
    c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
     'AdjustmentService', 'AdRuleService', 'AudienceSegmentService',
     'BaseRateService', 'CdnConfigurationService', 'CmsMetadataService',
     'CompanyService', 'ContactService', 'ContentBundleService',
     'ContentService', 'CreativeService', 'CreativeSetService',
     'CreativeTemplateService', 'CreativeWrapperService',
     'CustomFieldService', 'CustomTargetingService',
     'DaiAuthenticationKeyService', 'ExchangeRateService',
     'ForecastService', 'InventoryService', 'LabelService',
     'LineItemCreativeAssociationService', 'LineItemService',
     'LineItemTemplateService', 'LiveStreamEventService',
     'MobileApplicationService', 'NativeStyleService', 'NetworkService',
     'OrderService', 'PackageService', 'PlacementService',
     'PremiumRateService', 'ProductService', 'ProductPackageService',
     'ProductPackageItemService', 'ProductTemplateService',
     'ProposalLineItemService', 'ProposalService',
     'PublisherQueryLanguageService', 'RateCardService',
     'ReconciliationOrderReportService', 'ReconciliationReportRowService',
     'ReconciliationLineItemReportService',
     'ReconciliationReportService', 'ReportService',
     'SuggestedAdUnitService', 'TeamService', 'UserService',
     'UserTeamAssociationService', 'WorkflowRequestService'),
  'v201905'=
    c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
     'AdjustmentService', 'AdRuleService', 'AudienceSegmentService',
     'BaseRateService', 'CdnConfigurationService', 'CmsMetadataService',
     'CompanyService', 'ContactService', 'ContentBundleService',
     'ContentService', 'CreativeService', 'CreativeSetService',
     'CreativeTemplateService', 'CreativeWrapperService',
     'CustomFieldService', 'CustomTargetingService',
     'DaiAuthenticationKeyService', 'ExchangeRateService',
     'ForecastService', 'InventoryService', 'LabelService',
     'LineItemCreativeAssociationService', 'LineItemService',
     'LineItemTemplateService', 'LiveStreamEventService',
     'MobileApplicationService', 'NativeStyleService', 'NetworkService',
     'OrderService', 'PackageService', 'PlacementService',
     'PremiumRateService', 'ProductService', 'ProductPackageService',
     'ProductPackageItemService', 'ProductTemplateService',
     'ProposalLineItemService', 'ProposalService',
     'PublisherQueryLanguageService', 'RateCardService',
     'ReconciliationOrderReportService', 'ReconciliationReportRowService',
     'ReconciliationLineItemReportService',
     'ReconciliationReportService', 'ReportService',
     'SuggestedAdUnitService', 'TeamService', 'TargetingPresetService',
     'UserService', 'UserTeamAssociationService', 'WorkflowRequestService')  
)
